@@ -15,11 +15,11 @@ Module::Format::PerlMF_App - implements the perlmf command-line application.
 
 =head1 VERSION
 
-Version 0.0.6
+Version 0.0.7
 
 =cut
 
-our $VERSION = '0.0.6';
+our $VERSION = '0.0.7';
 
 =head1 SYNOPSIS
 
@@ -182,22 +182,18 @@ You can also look for information at:
 
 =over 4
 
+=item * MetaCPAN
+
+L<https://metacpan.org/release/Module-Format>
+
 =item * RT: CPAN's request tracker
 
 L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Module-Format>
 
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/Module-Format>
-
 =item * CPAN Ratings
 
 L<http://cpanratings.perl.org/d/Module-Format>
 
-=item * Search CPAN
-
-L<http://search.cpan.org/dist/Module-Format/>
-
 =back
 
 
